summaryrefslogtreecommitdiffstats
path: root/src/modules/objects/class_groupbox.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/modules/objects/class_groupbox.cpp')
-rw-r--r--src/modules/objects/class_groupbox.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/modules/objects/class_groupbox.cpp b/src/modules/objects/class_groupbox.cpp
index d0ecae08..a1f5c11f 100644
--- a/src/modules/objects/class_groupbox.cpp
+++ b/src/modules/objects/class_groupbox.cpp
@@ -29,7 +29,7 @@
#include "kvi_locale.h"
#include "kvi_iconmanager.h"
-// Tables used in $setAlignment , $tqalignment and in $setOrientation & $orientation
+// Tables used in $setAlignment , $alignment and in $setOrientation & $orientation
const char * const align_tbl[] = {
"Left",
@@ -60,7 +60,7 @@ const int align_cod[] = {
@description:
This widget can be used to display a groupbox.
It will be usually a parent for other child controls.
- You can either use a child tqlayout to manage the tqchildren geometries
+ You can either use a child tqlayout to manage the children geometries
or use $setColumnLayout to manage the tqlayout automatically.
@functions:
!fn: $setTitle(<text:String>)
@@ -89,14 +89,14 @@ const int align_cod[] = {
Returns the number of columns or rows in the groupbox.
!fn: $addSpace()
Adds an empty cell at the next free position.
- !fn: <string> $tqalignment()
- Returns the tqalignment of the group box title.
- !fn: $setAlignment(<tqalignment:string>)
- Set the tqalignment of the groupbox; Valid values are Left,Right,HCenter.
+ !fn: <string> $alignment()
+ Returns the alignment of the group box title.
+ !fn: $setAlignment(<alignment:string>)
+ Set the alignment of the groupbox; Valid values are Left,Right,HCenter.
!fn: $setOrientation<orientation:string>
Sets the group box's orientation. Valid values are:Qt::Horizontal,Qt::Vertical.
!fn: $setColumnLayout(<columns:integer>,<orientation:string>)
- Enables the automatic tqlayout management. The tqchildren are arranged in n columns with the specified orientation.[br]
+ Enables the automatic tqlayout management. The children are arranged in n columns with the specified orientation.[br]
Valid values for <orientation> are:Qt::Horizontal,Qt::Vertical.
@examples:
[example]
@@ -137,8 +137,8 @@ const int align_cod[] = {
%layoutbtn->$addwidget(%btnok,0,0)[br]
%layoutbtn->$addwidget(%btncancel,0,1)[br]
[br]
#And finally we create a main tqlayout with the groupbox (and its "tqchildren")[br]
#and fakewiget (with its buttons tqchildren).
%maintqlayout=$new(tqlayout,%widget)[br]
%maintqlayout->$setspacing(10)[br]
%maintqlayout->$setmargin(10)[br]
@@ -165,7 +165,7 @@ KVSO_BEGIN_REGISTERCLASS(KviKvsObject_groupbox,"groupbox","widget")
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"setColumns", functionSetColumns)
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"columns", functionColumns)
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"addSpace", functionAddSpace)
- KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"tqalignment", functionAlignment)
+ KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"alignment", functionAlignment)
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"setAlignment", functionSetAlignment)
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"setOrientation", functionSetOrientation)
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"isChecked", functionIsChecked)
@@ -310,7 +310,7 @@ bool KviKvsObject_groupbox::functionSetAlignment(KviKvsObjectFunctionCall *c)
{
TQString szAlign;
KVSO_PARAMETERS_BEGIN(c)
- KVSO_PARAMETER("tqalignment",KVS_PT_STRING,0,szAlign)
+ KVSO_PARAMETER("alignment",KVS_PT_STRING,0,szAlign)
KVSO_PARAMETERS_END(c)
if (!widget()) return true;
for(unsigned int i = 0; i < align_num; i++)
@@ -321,12 +321,12 @@ bool KviKvsObject_groupbox::functionSetAlignment(KviKvsObjectFunctionCall *c)
return true;
}
}
- c->warning(__tr2qs("Unknown tqalignment"));
+ c->warning(__tr2qs("Unknown alignment"));
return true;
}
bool KviKvsObject_groupbox::functionAlignment(KviKvsObjectFunctionCall *c)
{
- int mode = ((KviTalGroupBox *)widget())->tqalignment();
+ int mode = ((KviTalGroupBox *)widget())->alignment();
TQString szAlignment="";
for(unsigned int i = 0; i < align_num; i++)
{
@@ -137,8 +137,8 @@ const int align_cod[] = {
%layoutbtn->$addwidget(%btncancel,0,1)[br]
[br]
- #And finally we create a main tqlayout with the groupbox (and its "tqchildren")[br]
- #and fakewiget (with its buttons tqchildren).
+ #And finally we create a main tqlayout with the groupbox (and its "children")[br]
+ #and fakewiget (with its buttons children).
%maintqlayout=$new(tqlayout,%widget)[br]
%maintqlayout->$setspacing(10)[br]